@@ -7,8 +7,6 @@ use Time::HiRes 'time';
 
 our $VERSION = '1.09';
 
-no if $] >= 5.018, warnings => 'experimental::smartmatch';
-
 use constant PLUGIN_NAME => 'restrpc';
 
 use Dancer::RPCPlugin::CallbackResult;
@@ -28,15 +26,16 @@ register PLUGIN_NAME ,=> sub {
     my($self, $base_url, $arguments) = plugin_args(@_);
 
     my $publisher;
-    given ($arguments->{publish} // 'config') {
-        when (exists $dispatch_builder_map{$_}) {
+    GIVEN: {
+        local $_ = $arguments->{publish} // 'config';
+        exists($dispatch_builder_map{$_}) && do {
             $publisher = $dispatch_builder_map{$_};
-
             $arguments->{arguments} = plugin_setting() if $_ eq 'config';
-        }
-        default {
+            last GIVEN;
+        };
+        do {
             $publisher = $_;
-        }
+        };
     }
     my $dispatcher = $publisher->($arguments->{arguments}, $base_url);
 
