@@ -1,11 +1,15 @@
 package Dancer::RPCPlugin::DispatchMethodList;
 use warnings;
 use strict;
-use Params::Validate ':all';
 
 use Exporter 'import';
 our @EXPORT = ('list_methods');
 
+use Dancer::RPCPlugin::PluginNames;
+use Scalar::Util 'blessed';
+use Types::Standard qw/ StrMatch ArrayRef /;
+use Params::ValidationCompiler 'validation_for';
+
 =head1 NAME
 
 Dancer::RPCPlugin::DispatchMethodList - Class for maintaining a global methodlist.
@@ -16,13 +20,13 @@ Dancer::RPCPlugin::DispatchMethodList - Class for maintaining a global methodlis
     my $methods = Dancer::RPCPlugin::DispatchMethodList->new();
 
     $methods->set_partial(
-        protocol => <jsonrpc|xmlrpc>,
+        protocol => <jsonrpc|restrpc|xmlrpc>,
         endpoint => </configured>,
         methods  => [ @method_names ],
     );
 
     # ....
-    my $methods = list_methods(<any|jsonrpc|xmlrpc>);
+    my $method_list = $methods->list_methods(protocol => <any|jsonrpc|restrpc|xmlrpc>);
 
 =head1 DESCRIPTION
 
@@ -36,16 +40,16 @@ None!
 
 =head3 Responses
 
-    $singleton = bless $parameters, $class;
+    $_singleton = bless $parameters, $class;
 
 =cut
 
-my $singleton;
+my $_singleton;
 sub new {
-    return $singleton if $singleton;
+    return $_singleton if $_singleton;
 
     my $class = shift;
-    $singleton = bless {protocol => {}}, $class;
+    $_singleton = bless {protocol => {}}, $class;
 }
 
 =head2 $dml->set_partial(%parameters)
@@ -56,9 +60,9 @@ Named, list:
 
 =over
 
-=item protocol => <jsonrpc|xmlrpc>
+=item protocol => <jsonrpc|restrpc|xmlrpc> (required)
 
-=item endpoint => $endpoint
+=item endpoint => $endpoint                (required)
 
 =item methods => \@method_list
 
@@ -72,29 +76,29 @@ Named, list:
 
 sub set_partial {
     my $self = shift;
-    my $args = validate_with(
-        params => \@_,
-        spec   => {
-            protocol => {regex => qr/^(?:json|xml|rest)rpc$/, optional => 0},
-            endpoint => {regex => qr/^.*$/, optional => 0},
-            methods  => {type => ARRAYREF},
+    my $pn_re = Dancer::RPCPlugin::PluginNames->new->regex;
+    my %args = validation_for(
+        params => {
+            protocol => {type => StrMatch[ qr/^$pn_re$/ ], optional => 0},
+            endpoint => {type => StrMatch[ qr/^.*$/] , optional => 0},
+            methods  => {type => ArrayRef},
         },
-    );
-    $self->{protocols}{$args->{protocol}}{$args->{endpoint}} = $args->{methods};
+    )->(@_);
+    $self->{protocols}{$args{protocol}}{$args{endpoint}} = $args{methods};
     return $self;
 }
 
 =head2 list_methods(@parameters)
 
-This is not a method, but an exported function.
+Method that returns information about the dispatch-table.
 
 =head3 Parameters
 
-Positional, list:
+Positional, list
 
 =over
 
-=item $protocol => undef || <any|jsonrpc|xmlrpc>
+=item 1. $protocol => undef || <any|jsonrpc|restrpc|xmlrpc>  (optional)
 
 =back
 
@@ -123,15 +127,28 @@ In case of specified C<$protocol>:
 =cut
 
 sub list_methods {
-    my ($protocol) = validate_pos(
-        @_,
-        {default => 'any', regex => qr/^any|jsonrpc|xmlrpc$/, optional => 1}
-    );
-    if ($protocol eq 'any') {
-        return $singleton->{protocols};
+    my $self;
+    if (blessed($_[0])) {
+        $self = shift;
     }
     else {
-        return $singleton->{protocols}{$protocol};
+        $self = $_singleton;
+    }
+    my $pn_re = Dancer::RPCPlugin::PluginNames->new->regex;
+    my ($protocol) = validation_for(
+        params => [
+            {
+                type     => StrMatch [qr/^(?:any|$pn_re)$/],
+                default  => 'any',
+            },
+        ],
+    )->(@_);
+
+    if ($protocol eq 'any') {
+        return $self->{protocols};
+    }
+    else {
+        return $self->{protocols}{$protocol};
     }
 }
 
